==> freecad_0.21.2+dfsg1.orig.tar.xz: FreeCAD-0.21.2/src/Mod/Inspection/Gui/Resources/translations/Inspection_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>Скругленный прямоугольник</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation>Проверка...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation>Получить информацию о расстоянии</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>Скругленный прямоугольник</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation>Визуальная проверка...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="230"/>
      <source>Visual Inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation>Фактический</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>Объекты</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation>Номинальный</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>Параметр</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation>Поиск расстояния</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation> мм</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>Толщина</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="455"/>
      <source>Remove annotations</source>
      <translation>Удалить аннотации</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="456"/>
      <source>Do you want to remove all annotations?</source>
      <translation>Вы хотите удалить все аннотации?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="508"/>
      <source>Annotation</source>
      <translation>Заметка</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="511"/>
      <source>Leave info mode</source>
      <translation>Выйти из информационного режима</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="632"/>
      <source>Distance: &gt; %1</source>
      <translation>Расстояние: &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="635"/>
      <source>Distance: &lt; %1</source>
      <translation>Расстояние: &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="654"/>
      <location filename="../../ViewProviderInspection.cpp" line="670"/>
      <source>Distance: %1</source>
      <translation>Расстояние: %1</translation>
    </message>
  </context>
</TS>

==> freecad_1.0.0+dfsg.orig.tar.xz: FreeCAD-1.0.0/src/Mod/Inspection/Gui/Resources/translations/Inspection_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru" sourcelanguage="en">
  <context>
    <name>CmdInspectElement</name>
    <message>
      <location filename="../../Command.cpp" line="74"/>
      <source>Inspection</source>
      <translation>Инспекция</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="75"/>
      <source>Inspection...</source>
      <translation>Проверка...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="76"/>
      <source>Get distance information</source>
      <translation>Получить информацию о расстоянии</translation>
    </message>
  </context>
  <context>
    <name>CmdVisualInspection</name>
    <message>
      <location filename="../../Command.cpp" line="48"/>
      <source>Inspection</source>
      <translation>Инспекция</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="49"/>
      <source>Visual inspection...</source>
      <translation>Визуальная проверка...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="50"/>
      <location filename="../../Command.cpp" line="51"/>
      <source>Visual inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../VisualInspection.cpp" line="237"/>
      <source>Visual Inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
  </context>
  <context>
    <name>InspectionGui::VisualInspection</name>
    <message>
      <location filename="../../VisualInspection.ui" line="14"/>
      <source>Visual Inspection</source>
      <translation>Визуальная проверка</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="23"/>
      <source>Actual</source>
      <translation>Фактический</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="39"/>
      <location filename="../../VisualInspection.ui" line="66"/>
      <source>Objects</source>
      <translation>Объекты</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="50"/>
      <source>Nominal</source>
      <translation>Номинальный</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="77"/>
      <source>Parameter</source>
      <translation>Параметр</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="97"/>
      <source>Search distance</source>
      <translation>Поиск расстояния</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="129"/>
      <location filename="../../VisualInspection.ui" line="174"/>
      <source> mm</source>
      <translation> мм</translation>
    </message>
    <message>
      <location filename="../../VisualInspection.ui" line="145"/>
      <source>Thickness</source>
      <translation>Толщина</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="489"/>
      <source>Remove annotations</source>
      <translation>Удалить аннотации</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="490"/>
      <source>Do you want to remove all annotations?</source>
      <translation>Вы хотите удалить все аннотации?</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="548"/>
      <source>Annotation</source>
      <translation>Заметка</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="551"/>
      <source>Leave info mode</source>
      <translation>Выйти из информационного режима</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="682"/>
      <source>Distance: &gt; %1</source>
      <translation>Расстояние: &gt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="686"/>
      <source>Distance: &lt; %1</source>
      <translation>Расстояние: &lt; %1</translation>
    </message>
    <message>
      <location filename="../../ViewProviderInspection.cpp" line="706"/>
      <location filename="../../ViewProviderInspection.cpp" line="723"/>
      <source>Distance: %1</source>
      <translation>Расстояние: %1</translation>
    </message>
  </context>
</TS>
